(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[9109],{79109:function(t,a,n){"use strict";n.r(a);var e=n(69438),i=n.n(e);n(9680);i().Interaction.modes.neareach=function(t,a,n){var e,r={x:function(t,a){return Math.abs(t.x-a.x)},y:function(t,a){return Math.abs(t.y-a.y)},xy:function(t,a){return Math.pow(t.x-a.x,2)+Math.pow(t.y-a.y,2)}};e=a.native?{x:a.x,y:a.y}:i().helpers.getRelativePosition(a,t);var s,u=[],o=[],f=t.data.datasets;n.axis=n.axis||"xy";for(var x=r[n.axis],c={x:function(t){return t},y:function(t){return t},xy:function(t){return t*t}}[n.axis],h=0,v=f.length;h<v;++h)if(t.isDatasetVisible(h))for(var d=0,y=(s=t.getDatasetMeta(h)).data.length;d<y;++d){var l=s.data[d];if(!l._view.skip){var p=l._view,w=x(p,e),_=o[h];w<c(p.radius+p.hitRadius)&&(void 0===_||_>w)&&(o[h]=w,u[h]=l)}}return u.filter((function(t){return void 0!==t}))},a.default=i()}}]);
//# sourceMappingURL=chunk.2def4379f436959bab08.js.map